@@ -73,6 +73,9 @@ def _write_partition_image(image, image_info, device):
     disk_label = image_info.get('disk_label', 'msdos')
     image_mb = disk_utils.get_image_mb(image)
     root_mb = image_info['root_mb']
+
+    cpu_arch = hardware.dispatch_to_managers('get_cpus').architecture
+
     if image_mb > int(root_mb):
         msg = ('Root partition is too small for requested image. Image '
                'virtual size: {} MB, Root size: {} MB').format(image_mb,
@@ -88,7 +91,8 @@ def _write_partition_image(image, image_info, device):
                                        configdrive=configdrive,
                                        boot_option=boot_option,
                                        boot_mode=boot_mode,
-                                       disk_label=disk_label)
+                                       disk_label=disk_label,
+                                       cpu_arch=cpu_arch)
     except processutils.ProcessExecutionError as e:
         raise errors.ImageWriteError(device, e.exit_code, e.stdout, e.stderr)
 
@@ -144,8 +148,8 @@ def _message_format(msg, image_info, device, partition_uuids):
         root_uuid = partition_uuids.get('root uuid')
         efi_system_partition_uuid = (
             partition_uuids.get('efi system partition uuid'))
-        if (image_info.get('deploy_boot_mode') == 'uefi' and
-                image_info.get('boot_option') == 'local'):
+        if (image_info.get('deploy_boot_mode') == 'uefi'
+                and image_info.get('boot_option') == 'local'):
             result_msg = msg + 'root_uuid={} efi_system_partition_uuid={}'
             message = result_msg.format(image_info['id'], device,
                                         root_uuid,
@@ -461,8 +465,8 @@ class StandbyExtension(base.BaseAgentExtension):
                 LOG.debug('Already had %s cached, overwriting',
                           self.cached_image_id)
 
-            if (stream_raw_images and disk_format == 'raw' and
-                image_info.get('image_type') != 'partition'):
+            if (stream_raw_images and disk_format == 'raw'
+                    and image_info.get('image_type') != 'partition'):
                 self._stream_raw_image_onto_device(image_info, device)
             else:
                 self._cache_and_write_image(image_info, device)
